from __future__ import annotations

from .FXMenuCaption import FXMenuCaption


class FXMenuCascade(FXMenuCaption):
    """The cascade menu widget is used to bring up a sub menu from a pull down menu."""
